@@ -185,6 +185,7 @@ class FeatureAnalysis:
 
     def __init__(
             self,
+            col_dict: dict = None,
             convert_dict: dict = None,
             field_dict: dict = None,
             is_drop_corr: bool = True,
@@ -227,6 +228,12 @@ class FeatureAnalysis:
         time_cost: bool
             是否显示耗时
         """
+        self.col_dict = col_dict
+        if col_dict is not None:
+            self.col_dict_copy = {}
+            for k, vs in col_dict.items():
+                for v in vs:
+                    self.col_dict_copy[v] = k
         self.convert_dict = convert_dict
         self.field_dict = {} if field_dict is None else field_dict
         self.is_drop_corr = is_drop_corr
@@ -415,7 +422,15 @@ class FeatureAnalysis:
     ):
         bins_df = None,
         iv = None
-        type_ = identify_col(data, col)
+        if self.after_pretreatment:
+            if self.col_dict is None:
+                raise ValueError('对预处理之后的数据做数据分析请输入col_dict')
+            try:
+                type_ = self.col_dict_copy[col]
+            except KeyError:
+                type_ = identify_col(data, col)
+        else:
+            type_ = identify_col(data, col)
         if type_ == 'to_cla_col':
             bins_df, iv = cla_bin(data, col, label, self.convert_dict, self.final_box, self.after_pretreatment)
         if type_ == 'num_cla_col':
